Package: pboost
Title: Profile Boosting Framework for Parametric Models
Version: 0.4.11
Maintainer: Zengchao Xu <zengc.xu@aliyun.com>
Authors@R: 
    person("Zengchao", "Xu", , "zengc.xu@aliyun.com", role = c("aut", "cre", "cph"))
Description: 
    A profile boosting framework for feature selection in parametric models.
    It offers a unified interface pboost() and several wrapped models, including linear model, generalized linear models, quantile regression, Cox proportional hazards model, beta regression, spatial auto-regressive models.
Imports: stats, Matrix, MASS, betareg, quantreg, survival, Formula (>=
        1.2.5), glmnet, ncvreg, rqPen, spatialreg
License: GPL (>= 3)
Encoding: UTF-8
URL: https://github.com/paradoxical-rhapsody/pboost
BugReports: https://github.com/paradoxical-rhapsody/pboost/issues
Depends: R (>= 4.1.0)
RoxygenNote: 8.0.0
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-24 06:41:58 UTC; zengc
Author: Zengchao Xu [aut, cre, cph]
Repository: CRAN
Date/Publication: 2026-05-24 07:00:02 UTC
Built: R 4.6.0; ; 2026-05-24 09:33:10 UTC; unix
