# Generated by roxygen2: do not edit by hand

S3method(BIC,sarpboost)
S3method(EBIC,default)
S3method(coef,penaltyglmnet)
S3method(coef,penaltyncvreg)
S3method(coef,penaltyrq)
S3method(coef,sarpboost)
S3method(logLik,sarpboost)
S3method(residuals,sarpboost)
export(EBIC)
export(fbetareg)
export(fcoxph)
export(fglm)
export(fglm.fit)
export(flagsarlm)
export(flm)
export(flm.fit)
export(frq)
export(frq.fit)
export(frs)
export(fsar.fit)
export(get_rho)
export(pbetareg)
export(pboost)
export(pcoxph)
export(pen_glmnet)
export(pen_ncvreg)
export(pen_rq)
export(pen_sar)
export(pggm)
export(pglm)
export(pglm.fit)
export(plagsarlm)
export(plm)
export(plm.fit)
export(prq)
export(prq.fit)
export(psar.fit)
export(sar.fit)
export(set_rook_matrix)
import(Formula)
import(Matrix)
importFrom(MASS,ginv)
importFrom(betareg,betareg)
importFrom(betareg,betareg.control)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(ncvreg,cv.ncvreg)
importFrom(ncvreg,cv.ncvsurv)
importFrom(quantreg,rq)
importFrom(quantreg,rq.fit)
importFrom(quantreg,rq.wfit)
importFrom(rqPen,qic.select)
importFrom(rqPen,rq.pen)
importFrom(spatialreg,lagsarlm)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,lm)
importFrom(stats,lm.fit)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,nobs)
importFrom(stats,optimize)
importFrom(stats,predict)
importFrom(stats,qlogis)
importFrom(stats,residuals)
importFrom(stats,terms)
importFrom(survival,coxph)
importFrom(survival,coxph.fit)
