#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' 
#' @import Formula
#' @import Matrix
#' @importFrom betareg betareg
#' @importFrom betareg betareg.control
#' @importFrom glmnet cv.glmnet
#' @importFrom glmnet glmnet
#' @importFrom MASS ginv
#' @importFrom ncvreg cv.ncvreg
#' @importFrom ncvreg cv.ncvsurv
#' @importFrom quantreg rq
#' @importFrom rqPen qic.select
#' @importFrom rqPen rq.pen
#' @importFrom stats AIC
#' @importFrom stats as.formula
#' @importFrom stats BIC
#' @importFrom stats coef
#' @importFrom stats fitted
#' @importFrom stats formula
#' @importFrom stats gaussian
#' @importFrom stats glm
#' @importFrom stats glm.fit
#' @importFrom stats lm
#' @importFrom stats lm.fit
#' @importFrom stats logLik
#' @importFrom stats model.frame
#' @importFrom stats model.response
#' @importFrom stats na.omit
#' @importFrom stats nobs
#' @importFrom stats optimize
#' @importFrom stats predict
#' @importFrom stats qlogis
#' @importFrom stats residuals
#' @importFrom stats terms
#' @importFrom survival coxph
#> [1] "_PACKAGE"
## usethis namespace: end
NULL
