% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fsar.R
\name{flagsarlm}
\alias{flagsarlm}
\alias{fsar.fit}
\alias{fsar}
\title{Forward Stepwise Spatial Auto-Regressive Model}
\usage{
flagsarlm(
  formula,
  data = list(),
  listw,
  na.action,
  Durbin,
  type,
  method = "eigen",
  quiet = NULL,
  zero.policy = NULL,
  interval = NULL,
  tol.solve = .Machine$double.eps,
  trs = NULL,
  control = list(),
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)

fsar.fit(
  x,
  y,
  w,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{data}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{listw}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{na.action}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{Durbin}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{type}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{method}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{quiet}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{zero.policy}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{interval}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{tol.solve}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{trs}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{control}{Parameters passed to \link[spatialreg:lagsarlm]{spatialreg::lagsarlm}.}

\item{selectFun}{Parameter passed to \link{frs}.}

\item{stopFun}{Parameter passed to \link{frs}.}

\item{keep}{Parameter passed to \link{frs}.}

\item{maxK}{Parameter passed to \link{frs}.}

\item{verbose}{Parameter passed to \link{frs}.}

\item{x}{Matrix of covariates.}

\item{y}{Vector of response.}

\item{w}{Weight matrix (row-sum scaled being one).}
}
\value{
Model object fitted on the selected features.
}
\description{
Forward stepwise strategy for spatial auto-regressive model.
}
