% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/flm.R
\name{flm}
\alias{flm}
\alias{flm.fit}
\title{Forward Regression Selection for Linear Models.}
\usage{
flm(
  formula,
  data,
  subset,
  weights,
  na.action,
  method = "qr",
  model = TRUE,
  x = FALSE,
  y = FALSE,
  qr = TRUE,
  singular.ok = TRUE,
  contrasts = NULL,
  offset,
  ...,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)

flm.fit(
  x,
  y,
  offset = NULL,
  method = "qr",
  tol = 1e-07,
  singular.ok = TRUE,
  ...,
  selectFun = "logLik",
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link{lm}.}

\item{data}{Parameter passed to \link{lm}.}

\item{subset}{Parameter passed to \link{lm}.}

\item{weights}{Parameter passed to \link{lm}.}

\item{na.action}{Parameter passed to \link{lm}.}

\item{method}{Parameter passed to \link{lm}.}

\item{model}{Parameter passed to \link{lm}.}

\item{x}{Parameter passed to \link{lm}.}

\item{y}{Parameter passed to \link{lm}.}

\item{qr}{Parameter passed to \link{lm}.}

\item{singular.ok}{Parameter passed to \link{lm}.}

\item{contrasts}{Parameter passed to \link{lm}.}

\item{offset}{Parameter passed to \link{lm} or \link{lm.fit}.}

\item{...}{Parameters passed to \link{lm} or \link{lm.fit}.}

\item{selectFun}{Parameter passed to \link{frs}.}

\item{stopFun}{Parameter passed to \link{frs}.}

\item{keep}{Parameter passed to \link{frs}.}

\item{maxK}{Parameter passed to \link{frs}.}

\item{verbose}{Parameter passed to \link{frs}.}

\item{tol}{Parameter passed to \link{lm.fit}.}
}
\value{
A \code{lm} model object fitted on the selected features.
}
\description{
\code{flm()} inherits the usage of the function \link{lm}, and performs forward regression selection for linear models.
}
