% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/penalty-glmnet.R
\name{coef.penaltyglmnet}
\alias{coef.penaltyglmnet}
\title{Extract Coefficients from Lasso Penalized Models}
\usage{
\method{coef}{penaltyglmnet}(object, ...)
}
\arguments{
\item{object}{Object.}

\item{...}{Additional arguments (not used).}
}
\value{
Named vector of non-zero coefficients of under cross-validation error.
}
\description{
Extract Coefficients from Lasso Penalized Models
}
