% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pboost.R
\name{pboost}
\alias{pboost}
\title{Profile Boosting Framework}
\usage{
pboost(
  yvec,
  xmat,
  fitFun,
  scoreFun,
  stopFun = "EBIC",
  ...,
  use.formula = TRUE,
  use.intercept = TRUE,
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{yvec}{Response vector.}

\item{xmat}{Numeric feature matrix.}

\item{fitFun}{Function to fit the empirical risk function in
the form \code{fitFun(formula, data, ...)}.}

\item{scoreFun}{Function to compute the derivative, denoted by \eqn{\frac{\partial \ell(y, \eta)}{\partial \eta}}, of empirical risk function in the form \code{scoreFun(object)}, where \code{object} is returned by \code{fitFun}.
\code{scoreFun()} should return a vector with the same length of \code{y} in \code{data}.}

\item{stopFun}{Stopping rule for profile boosting, which has the form
\code{stopFun(object)} to evaluate the performance of model \code{object} returned
by \code{fitFun}, such as \link{EBIC} or \link{BIC}.}

\item{...}{Additional arguments to be passed to \code{fitFun}.}

\item{use.formula}{Whether to use formula interface for model fitting. Default to \code{TRUE}.
When \code{use.formula=TRUE}, the the model fitting function has the form \code{fitFun(formula, data, ...)}; otherwise, \code{fitFun(x, y, ...)}.}

\item{use.intercept}{Include intercept in the model fitting? Valid only when \code{use.formula=TRUE}.}

\item{keep}{Vector of indices or feature names initial features to include.}

\item{maxK}{Maximal number of identified features.
If \code{maxK} is specified, it will suppress \code{stopFun}, saying that the
profile boosting continues until the procedure identifies \code{maxK} features.
The pre-specified features in \code{keep} are counted toward \code{maxK}.}

\item{verbose}{Print the procedure path?}
}
\value{
Model object fitted on the selected features.
}
\description{
\code{pboost()} is the generic workhorse function of profile boosting
framework for parametric regression.
}
\seealso{
\link{pbetareg}, \link{pcoxph}, \link{pglm}, \link{plm}, \link{prq}, \link{psar}.
}
