% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/frs.R
\name{frs}
\alias{frs}
\title{Forward Regression Selection Framework}
\usage{
frs(
  yvec,
  xmat,
  fitFun,
  ...,
  use.formula = TRUE,
  use.intercept = TRUE,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{yvec}{See \link{pboost}.}

\item{xmat}{See \link{pboost}.}

\item{fitFun}{See \link{pboost}.}

\item{...}{See \link{pboost}.}

\item{use.formula}{See \link{pboost}.}

\item{use.intercept}{See \link{pboost}.}

\item{selectFun}{A function to evaluate the importance of an unselected feature when it is added to current model.
The default is \code{logLik}, meaning that the feature with the largest post-added log-likelihood is identified as the next one to be added to the model.
Note that \code{selectFun} is only used for selecting features, and it does not affect the stopping rule of forward regression selection, which is determined by \code{stopFun}.}

\item{stopFun}{See \link{pboost}.}

\item{keep}{See \link{pboost}.}

\item{maxK}{See \link{pboost}.}

\item{verbose}{See \link{pboost}.}
}
\value{
Model object fitted on the selected features.
}
\description{
\code{frs()} is a generic workhorse function of forward regression selection for parametric regression.
}
\seealso{
\link{fbetareg}, \link{fcoxph}, \link{fglm}, \link{flm}, \link{frq}, \link{fsar}.
}
