% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/penalty-rq.R
\name{coef.penaltyrq}
\alias{coef.penaltyrq}
\title{Extract Coefficients from Non-Convex Penalized Models}
\usage{
\method{coef}{penaltyrq}(object, ...)
}
\arguments{
\item{object}{Object.}

\item{...}{Additional arguments (not used).}
}
\value{
A named vector of coefficients.
}
\description{
Extract Coefficients from Non-Convex Penalized Models
}
