% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sar.R
\name{sar.model}
\alias{sar.model}
\alias{get_rho}
\alias{sar.fit}
\alias{residuals.sarpboost}
\alias{logLik.sarpboost}
\alias{BIC.sarpboost}
\alias{coef.sarpboost}
\alias{set_rook_matrix}
\title{Functions for Spatial Auto-regressive Model}
\usage{
get_rho(x, y, w)

sar.fit(x, y, w)

\method{residuals}{sarpboost}(object, ...)

\method{logLik}{sarpboost}(object, ...)

\method{BIC}{sarpboost}(object, ...)

\method{coef}{sarpboost}(object, ...)

set_rook_matrix(rNum, cNum)
}
\arguments{
\item{x}{Numeric feature matrix.}

\item{y}{Response vector.}

\item{w}{Weight matrix (row-sum scaled).}

\item{object}{Object.}

\item{...}{Arguments.}

\item{rNum}{Number of row units in Rook structure.}

\item{cNum}{Number of column units in Rook structure.}
}
\value{
Value or list.
}
\description{
\itemize{
\item \code{get_rho()}: MLE of \eqn{\rho} in SAR model. See \link{psar}.
\item \code{sar.fit()}: Fit SAR model with given \eqn{\rho}.
\item \code{set_rook_matrix()}: Construct Rook weight adjacency matrix.
\item \code{logLik()}, \code{BIC()}, \code{residuals()}, \code{coef()}.
}
}
