% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/frq.R
\name{frq}
\alias{frq}
\title{Forward Regression Selection for Quantile Regression Models}
\usage{
frq(
  formula,
  tau = 0.5,
  data,
  subset,
  weights,
  na.action,
  method = "br",
  model = TRUE,
  contrasts = NULL,
  ...,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{tau}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{data}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{subset}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{weights}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{na.action}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{method}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{model}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{contrasts}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{...}{Parameters passed to \link[quantreg:rq]{quantreg::rq}.}

\item{selectFun}{Parameter passed to \link{frs}.}

\item{stopFun}{Parameter passed to \link{frs}.}

\item{keep}{Parameter passed to \link{frs}.}

\item{maxK}{Parameter passed to \link{frs}.}

\item{verbose}{Parameter passed to \link{frs}.}
}
\description{
\code{frq()} inherits the usage of the function \link[quantreg:rq]{quantreg::rq}, and performs forward regression selection for quantile regression models.
}
