% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plm.R
\name{plm}
\alias{plm}
\alias{plm.fit}
\title{Profile Boosting for Linear Models.}
\usage{
plm(
  formula,
  data,
  subset,
  weights,
  na.action,
  method = "qr",
  model = TRUE,
  x = FALSE,
  y = FALSE,
  qr = TRUE,
  singular.ok = TRUE,
  contrasts = NULL,
  offset,
  ...,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)

plm.fit(
  x,
  y,
  offset = NULL,
  method = "qr",
  tol = 1e-07,
  singular.ok = TRUE,
  ...,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link{lm}.}

\item{data}{Parameter passed to \link{lm}.}

\item{subset}{Parameter passed to \link{lm}.}

\item{weights}{Parameter passed to \link{lm}.}

\item{na.action}{Parameter passed to \link{lm}.}

\item{method}{Parameter passed to \link{lm}.}

\item{model}{Parameter passed to \link{lm}.}

\item{x}{Parameter passed to \link{lm}.}

\item{y}{Parameter passed to \link{lm}.}

\item{qr}{Parameter passed to \link{lm}.}

\item{singular.ok}{Parameter passed to \link{lm}.}

\item{contrasts}{Parameter passed to \link{lm}.}

\item{offset}{Parameter passed to \link{lm} or \link{lm.fit}.}

\item{...}{Parameters passed to \link{lm} or \link{lm.fit}.}

\item{stopFun}{Parameter passed to \link{pboost}.}

\item{keep}{Parameter passed to \link{pboost}.}

\item{maxK}{Parameter passed to \link{pboost}.}

\item{verbose}{Parameter passed to \link{pboost}.}

\item{tol}{Parameter passed to \link{lm.fit}.}
}
\value{
A \code{lm} model object fitted on the selected features.
}
\description{
\link{plm} inherits the usage of the built-in function \link{lm}.
}
\details{
\code{plm} is an equivalent implementation to the sequential lasso method
proposed by Luo and Chen(2014, \doi{10.1080/01621459.2013.877275}).
}
\examples{
set.seed(2026)
n <- 300
p <- 200
x <- matrix(rnorm(n*p), n)

eta <- drop( x[, 1:3] \%*\% runif(3, 1.0, 1.5) )
y <- rnorm(n, eta, sd=sd(eta))
DF <- data.frame(y, x)

plm(y ~ ., DF, verbose=TRUE)
plm(y ~ ., DF, stopFun=BIC, verbose=TRUE)
pboost(y, x, lm, residuals, verbose=TRUE)

flm(y ~ ., DF, verbose=TRUE)
flm(y ~ ., DF, stopFun=BIC, verbose=TRUE)
frs(y, x, lm, verbose=TRUE)

}
\references{
\itemize{
\item Zengchao Xu, Shan Luo and Zehua Chen (2022). Partial profile score feature
selection in high-dimensional generalized linear interaction models.
Statistics and Its Interface. \doi{10.4310/21-SII706}
\item Shan Luo and Zehua Chen (2014). A Sequential Lasso Method for Feature Selection
with Ultra-High Dimensional Feature Space. Journal of the American Statistical
Association, 109(507):223–232. \doi{10.1080/01621459.2013.877275}
}
}
