% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fcoxph.R
\name{fcoxph}
\alias{fcoxph}
\title{Forward Regression Selection for Cox proportional hazards Model}
\usage{
fcoxph(
  formula,
  data,
  weights,
  subset,
  na.action,
  init,
  control,
  ties = c("efron", "breslow", "exact"),
  singular.ok = TRUE,
  robust,
  model = FALSE,
  x = FALSE,
  y = TRUE,
  tt,
  method = ties,
  id,
  cluster,
  istate,
  statedata,
  nocenter = c(-1, 0, 1),
  ...,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{data}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{weights}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{subset}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{na.action}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{init}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{control}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{ties}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{singular.ok}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{robust}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{model}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{x}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{y}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{tt}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{method}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{id}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{cluster}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{istate}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{statedata}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{nocenter}{Parameter passed to \link[survival:coxph]{survival::coxph}.}

\item{...}{Parameters passed to \link[survival:coxph]{survival::coxph}.}

\item{selectFun}{Parameter passed to \link{frs}.}

\item{stopFun}{Parameter passed to \link{frs}.}

\item{keep}{Parameter passed to \link{frs}.}

\item{maxK}{Parameter passed to \link{frs}.}

\item{verbose}{Parameter passed to \link{frs}.}
}
\value{
A \code{coxph} model object fitted on the selected features.
}
\description{
Forward regression selection for Cox model.
}
