% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pbetareg.R
\name{pbetareg}
\alias{pbetareg}
\title{Profile Boosting for Beta Regression}
\usage{
pbetareg(
  formula,
  data,
  subset,
  na.action,
  weights,
  offset,
  link = c("logit", "probit", "cloglog", "cauchit", "log", "loglog"),
  link.phi = NULL,
  type = c("ML", "BC", "BR"),
  dist = NULL,
  nu = NULL,
  control = betareg.control(...),
  model = TRUE,
  y = TRUE,
  x = FALSE,
  ...,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{data}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{subset}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{na.action}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{weights}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{offset}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{link}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{link.phi}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{type}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{dist}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{nu}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{control}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{model}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{y}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{x}{Parameter passed to \link[betareg:betareg]{betareg::betareg}.}

\item{...}{Parameters passed to \link[betareg:betareg]{betareg::betareg}.}

\item{stopFun}{Parameter passed to \link{pboost}.}

\item{keep}{Parameter passed to \link{pboost}.}

\item{maxK}{Parameter passed to \link{pboost}.}

\item{verbose}{Parameter passed to \link{pboost}.}
}
\value{
A \code{betareg} model object fitted on the selected features.
}
\description{
\link{pbetareg} inherits the usage of \link[betareg:betareg]{betareg::betareg}.
}
\examples{
\dontrun{
set.seed(2026)
n <- 300
p <- 20
x <- matrix(runif(n*p), n)
mu <- runif(n)
phi <- 1.0

shape1 <- mu * phi
shape2 <- (1-mu) * phi
y <- rbeta(n, shape1, shape2)
DF <- data.frame(y, x)

pbetareg(y ~ ., DF, verbose=TRUE)
fbetareg(y ~ ., DF, verbose=TRUE)
}

}
