% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prq.R
\name{prq}
\alias{prq}
\title{Profile Boosting for Quantile Regression Models}
\usage{
prq(
  formula,
  tau = 0.5,
  data,
  subset,
  weights,
  na.action,
  method = "br",
  model = TRUE,
  contrasts = NULL,
  ...,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{tau}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{data}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{subset}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{weights}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{na.action}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{method}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{model}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{contrasts}{Parameter passed to \link[quantreg:rq]{quantreg::rq}.}

\item{...}{Parameters passed to \link[quantreg:rq]{quantreg::rq}.}

\item{stopFun}{Parameter passed to \link{pboost}.}

\item{keep}{Parameter passed to \link{pboost}.}

\item{maxK}{Parameter passed to \link{pboost}.}

\item{verbose}{Parameter passed to \link{pboost}.}
}
\value{
A \code{rq} model object fitted on the selected features.
}
\description{
\link{prq} inherits the usage of the function \link[quantreg:rq]{quantreg::rq}.
}
\examples{
library(quantreg)
set.seed(2026)
n <- 300
p <- 20
x <- matrix(rnorm(n*p), n)

eta <- drop( x[, 1:3] \%*\% runif(3, 1.0, 1.5) )
y <- eta + (1.0 + x[, 3]) * rnorm(n)
DF <- data.frame(y, x)

tau <- 0.5
prq(y ~ ., tau, DF, verbose=TRUE)

BIC <- function(obj) AIC(obj, k=-1)
prq(y ~ ., tau, DF, stopFun=BIC, verbose=TRUE)
frq(y ~ ., tau, DF, stopFun=BIC, verbose=TRUE)

scoreFun <- function(object)
   return(ifelse(object[["y"]] < fitted(object), tau - 1, tau))

pboost(y, x, rq, scoreFun, BIC, tau=tau, verbose=TRUE)

}
