% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pboost-package.R
\docType{package}
\name{pboost-package}
\alias{pboost-package}
\title{pboost: Profile Boosting Framework for Parametric Models}
\description{
A profile boosting framework for feature selection in parametric models. It offers a unified interface pboost() and several wrapped models, including linear model, generalized linear models, quantile regression, Cox proportional hazards model, beta regression, spatial auto-regressive models.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/paradoxical-rhapsody/pboost}
  \item Report bugs at \url{https://github.com/paradoxical-rhapsody/pboost/issues}
}

}
\author{
\strong{Maintainer}: Zengchao Xu \email{zengc.xu@aliyun.com} [copyright holder]

}
\keyword{internal}
