% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fglm.R
\name{fglm}
\alias{fglm}
\alias{fglm.fit}
\title{Forward Regression Selection for Generalized Linear Models}
\usage{
fglm(
  formula,
  family = gaussian,
  data,
  weights,
  subset,
  na.action,
  start = NULL,
  etastart,
  mustart,
  offset,
  control = list(...),
  model = TRUE,
  method = "glm.fit",
  x = FALSE,
  y = TRUE,
  singular.ok = TRUE,
  contrasts = NULL,
  ...,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)

fglm.fit(
  x,
  y,
  weights = rep.int(1, NROW(y)),
  start = NULL,
  etastart = NULL,
  mustart = NULL,
  offset = rep.int(0, NROW(y)),
  family = gaussian(),
  control = list(),
  intercept = TRUE,
  singular.ok = TRUE,
  selectFun = "logLik",
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)
}
\arguments{
\item{formula}{Parameter passed to \link{glm}.}

\item{family}{Parameter passed to \link{glm}.}

\item{data}{Parameter passed to \link{glm}.}

\item{weights}{Parameter passed to \link{glm}.}

\item{subset}{Parameter passed to \link{glm}.}

\item{na.action}{Parameter passed to \link{glm}.}

\item{start}{Parameter passed to \link{glm}.}

\item{etastart}{Parameter passed to \link{glm}.}

\item{mustart}{Parameter passed to \link{glm}.}

\item{offset}{Parameter passed to \link{glm}.}

\item{control}{Parameter passed to \link{glm}.}

\item{model}{Parameter passed to \link{glm}.}

\item{method}{Parameter passed to \link{glm}.}

\item{x}{Parameter passed to \link{glm}.}

\item{y}{Parameter passed to \link{glm}.}

\item{singular.ok}{Parameter passed to \link{glm}.}

\item{contrasts}{Parameter passed to \link{glm}.}

\item{...}{Parameters passed to \link{glm}.}

\item{selectFun}{Parameter passed to \link{frs}.}

\item{stopFun}{Parameter passed to \link{frs}.}

\item{keep}{Parameter passed to \link{frs}.}

\item{maxK}{Parameter passed to \link{frs}.}

\item{verbose}{Parameter passed to \link{frs}.}

\item{intercept}{Parameter passed to \link{glm.fit}.}
}
\value{
A \code{glm} model object fitted on the selected features.
}
\description{
\code{fglm()} inherits the usage of \link{glm}, and performs forward regression selection for generalized linear models.
}
